@@ -14,9 +14,8 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
+from boto3.botocore_stubs import ClientError as BotocoreClientError
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
-from botocore.paginate import Paginator as Boto3Paginator
 
 from mypy_boto3_codebuild.paginator import (
     DescribeCodeCoveragesPaginator,
@@ -102,17 +101,17 @@ __all__ = ("CodeBuildClient",)
 
 
 class Exceptions:
-    AccountLimitExceededException: Type[Boto3ClientError]
-    ClientError: Type[Boto3ClientError]
-    InvalidInputException: Type[Boto3ClientError]
-    OAuthProviderException: Type[Boto3ClientError]
-    ResourceAlreadyExistsException: Type[Boto3ClientError]
-    ResourceNotFoundException: Type[Boto3ClientError]
+    AccountLimitExceededException: Type[BotocoreClientError]
+    ClientError: Type[BotocoreClientError]
+    InvalidInputException: Type[BotocoreClientError]
+    OAuthProviderException: Type[BotocoreClientError]
+    ResourceAlreadyExistsException: Type[BotocoreClientError]
+    ResourceNotFoundException: Type[BotocoreClientError]
 
 
 class CodeBuildClient:
     """
-    [CodeBuild.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client)
+    [CodeBuild.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client)
     """
 
     meta: ClientMeta
@@ -120,39 +119,39 @@ class CodeBuildClient:
 
     def batch_delete_builds(self, ids: List[str]) -> BatchDeleteBuildsOutputTypeDef:
         """
-        [Client.batch_delete_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.batch_delete_builds)
+        [Client.batch_delete_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.batch_delete_builds)
         """
 
     def batch_get_build_batches(self, ids: List[str]) -> BatchGetBuildBatchesOutputTypeDef:
         """
-        [Client.batch_get_build_batches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.batch_get_build_batches)
+        [Client.batch_get_build_batches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.batch_get_build_batches)
         """
 
     def batch_get_builds(self, ids: List[str]) -> BatchGetBuildsOutputTypeDef:
         """
-        [Client.batch_get_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.batch_get_builds)
+        [Client.batch_get_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.batch_get_builds)
         """
 
     def batch_get_projects(self, names: List[str]) -> BatchGetProjectsOutputTypeDef:
         """
-        [Client.batch_get_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.batch_get_projects)
+        [Client.batch_get_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.batch_get_projects)
         """
 
     def batch_get_report_groups(
         self, reportGroupArns: List[str]
     ) -> BatchGetReportGroupsOutputTypeDef:
         """
-        [Client.batch_get_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.batch_get_report_groups)
+        [Client.batch_get_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.batch_get_report_groups)
         """
 
     def batch_get_reports(self, reportArns: List[str]) -> BatchGetReportsOutputTypeDef:
         """
-        [Client.batch_get_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.batch_get_reports)
+        [Client.batch_get_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.batch_get_reports)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.can_paginate)
         """
 
     def create_project(
@@ -179,7 +178,7 @@ class CodeBuildClient:
         buildBatchConfig: "ProjectBuildBatchConfigTypeDef" = None,
     ) -> CreateProjectOutputTypeDef:
         """
-        [Client.create_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.create_project)
+        [Client.create_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.create_project)
         """
 
     def create_report_group(
@@ -190,7 +189,7 @@ class CodeBuildClient:
         tags: List["TagTypeDef"] = None,
     ) -> CreateReportGroupOutputTypeDef:
         """
-        [Client.create_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.create_report_group)
+        [Client.create_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.create_report_group)
         """
 
     def create_webhook(
@@ -201,42 +200,42 @@ class CodeBuildClient:
         buildType: Literal["BUILD", "BUILD_BATCH"] = None,
     ) -> CreateWebhookOutputTypeDef:
         """
-        [Client.create_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.create_webhook)
+        [Client.create_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.create_webhook)
         """
 
     def delete_build_batch(self, id: str) -> DeleteBuildBatchOutputTypeDef:
         """
-        [Client.delete_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.delete_build_batch)
+        [Client.delete_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.delete_build_batch)
         """
 
     def delete_project(self, name: str) -> Dict[str, Any]:
         """
-        [Client.delete_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.delete_project)
+        [Client.delete_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.delete_project)
         """
 
     def delete_report(self, arn: str) -> Dict[str, Any]:
         """
-        [Client.delete_report documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.delete_report)
+        [Client.delete_report documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.delete_report)
         """
 
     def delete_report_group(self, arn: str) -> Dict[str, Any]:
         """
-        [Client.delete_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.delete_report_group)
+        [Client.delete_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.delete_report_group)
         """
 
     def delete_resource_policy(self, resourceArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.delete_resource_policy)
+        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.delete_resource_policy)
         """
 
     def delete_source_credentials(self, arn: str) -> DeleteSourceCredentialsOutputTypeDef:
         """
-        [Client.delete_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.delete_source_credentials)
+        [Client.delete_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.delete_source_credentials)
         """
 
     def delete_webhook(self, projectName: str) -> Dict[str, Any]:
         """
-        [Client.delete_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.delete_webhook)
+        [Client.delete_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.delete_webhook)
         """
 
     def describe_code_coverages(
@@ -250,7 +249,7 @@ class CodeBuildClient:
         maxLineCoveragePercentage: float = None,
     ) -> DescribeCodeCoveragesOutputTypeDef:
         """
-        [Client.describe_code_coverages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.describe_code_coverages)
+        [Client.describe_code_coverages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.describe_code_coverages)
         """
 
     def describe_test_cases(
@@ -261,7 +260,7 @@ class CodeBuildClient:
         filter: TestCaseFilterTypeDef = None,
     ) -> DescribeTestCasesOutputTypeDef:
         """
-        [Client.describe_test_cases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.describe_test_cases)
+        [Client.describe_test_cases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.describe_test_cases)
         """
 
     def generate_presigned_url(
@@ -272,12 +271,12 @@ class CodeBuildClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.generate_presigned_url)
         """
 
     def get_resource_policy(self, resourceArn: str) -> GetResourcePolicyOutputTypeDef:
         """
-        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.get_resource_policy)
+        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.get_resource_policy)
         """
 
     def import_source_credentials(
@@ -289,12 +288,12 @@ class CodeBuildClient:
         shouldOverwrite: bool = None,
     ) -> ImportSourceCredentialsOutputTypeDef:
         """
-        [Client.import_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.import_source_credentials)
+        [Client.import_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.import_source_credentials)
         """
 
     def invalidate_project_cache(self, projectName: str) -> Dict[str, Any]:
         """
-        [Client.invalidate_project_cache documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.invalidate_project_cache)
+        [Client.invalidate_project_cache documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.invalidate_project_cache)
         """
 
     def list_build_batches(
@@ -305,7 +304,7 @@ class CodeBuildClient:
         nextToken: str = None,
     ) -> ListBuildBatchesOutputTypeDef:
         """
-        [Client.list_build_batches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.list_build_batches)
+        [Client.list_build_batches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.list_build_batches)
         """
 
     def list_build_batches_for_project(
@@ -317,14 +316,14 @@ class CodeBuildClient:
         nextToken: str = None,
     ) -> ListBuildBatchesForProjectOutputTypeDef:
         """
-        [Client.list_build_batches_for_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.list_build_batches_for_project)
+        [Client.list_build_batches_for_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.list_build_batches_for_project)
         """
 
     def list_builds(
         self, sortOrder: Literal["ASCENDING", "DESCENDING"] = None, nextToken: str = None
     ) -> ListBuildsOutputTypeDef:
         """
-        [Client.list_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.list_builds)
+        [Client.list_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.list_builds)
         """
 
     def list_builds_for_project(
@@ -334,12 +333,12 @@ class CodeBuildClient:
         nextToken: str = None,
     ) -> ListBuildsForProjectOutputTypeDef:
         """
-        [Client.list_builds_for_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.list_builds_for_project)
+        [Client.list_builds_for_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.list_builds_for_project)
         """
 
     def list_curated_environment_images(self) -> ListCuratedEnvironmentImagesOutputTypeDef:
         """
-        [Client.list_curated_environment_images documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.list_curated_environment_images)
+        [Client.list_curated_environment_images documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.list_curated_environment_images)
         """
 
     def list_projects(
@@ -349,7 +348,7 @@ class CodeBuildClient:
         nextToken: str = None,
     ) -> ListProjectsOutputTypeDef:
         """
-        [Client.list_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.list_projects)
+        [Client.list_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.list_projects)
         """
 
     def list_report_groups(
@@ -360,7 +359,7 @@ class CodeBuildClient:
         maxResults: int = None,
     ) -> ListReportGroupsOutputTypeDef:
         """
-        [Client.list_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.list_report_groups)
+        [Client.list_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.list_report_groups)
         """
 
     def list_reports(
@@ -371,7 +370,7 @@ class CodeBuildClient:
         filter: ReportFilterTypeDef = None,
     ) -> ListReportsOutputTypeDef:
         """
-        [Client.list_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.list_reports)
+        [Client.list_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.list_reports)
         """
 
     def list_reports_for_report_group(
@@ -383,7 +382,7 @@ class CodeBuildClient:
         filter: ReportFilterTypeDef = None,
     ) -> ListReportsForReportGroupOutputTypeDef:
         """
-        [Client.list_reports_for_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.list_reports_for_report_group)
+        [Client.list_reports_for_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.list_reports_for_report_group)
         """
 
     def list_shared_projects(
@@ -394,7 +393,7 @@ class CodeBuildClient:
         nextToken: str = None,
     ) -> ListSharedProjectsOutputTypeDef:
         """
-        [Client.list_shared_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.list_shared_projects)
+        [Client.list_shared_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.list_shared_projects)
         """
 
     def list_shared_report_groups(
@@ -405,22 +404,22 @@ class CodeBuildClient:
         maxResults: int = None,
     ) -> ListSharedReportGroupsOutputTypeDef:
         """
-        [Client.list_shared_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.list_shared_report_groups)
+        [Client.list_shared_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.list_shared_report_groups)
         """
 
     def list_source_credentials(self) -> ListSourceCredentialsOutputTypeDef:
         """
-        [Client.list_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.list_source_credentials)
+        [Client.list_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.list_source_credentials)
         """
 
     def put_resource_policy(self, policy: str, resourceArn: str) -> PutResourcePolicyOutputTypeDef:
         """
-        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.put_resource_policy)
+        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.put_resource_policy)
         """
 
     def retry_build(self, id: str = None, idempotencyToken: str = None) -> RetryBuildOutputTypeDef:
         """
-        [Client.retry_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.retry_build)
+        [Client.retry_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.retry_build)
         """
 
     def retry_build_batch(
@@ -430,7 +429,7 @@ class CodeBuildClient:
         retryType: Literal["RETRY_ALL_BUILDS", "RETRY_FAILED_BUILDS"] = None,
     ) -> RetryBuildBatchOutputTypeDef:
         """
-        [Client.retry_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.retry_build_batch)
+        [Client.retry_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.retry_build_batch)
         """
 
     def start_build(
@@ -487,7 +486,7 @@ class CodeBuildClient:
         debugSessionEnabled: bool = None,
     ) -> StartBuildOutputTypeDef:
         """
-        [Client.start_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.start_build)
+        [Client.start_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.start_build)
         """
 
     def start_build_batch(
@@ -543,17 +542,17 @@ class CodeBuildClient:
         buildBatchConfigOverride: "ProjectBuildBatchConfigTypeDef" = None,
     ) -> StartBuildBatchOutputTypeDef:
         """
-        [Client.start_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.start_build_batch)
+        [Client.start_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.start_build_batch)
         """
 
     def stop_build(self, id: str) -> StopBuildOutputTypeDef:
         """
-        [Client.stop_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.stop_build)
+        [Client.stop_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.stop_build)
         """
 
     def stop_build_batch(self, id: str) -> StopBuildBatchOutputTypeDef:
         """
-        [Client.stop_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.stop_build_batch)
+        [Client.stop_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.stop_build_batch)
         """
 
     def update_project(
@@ -580,7 +579,7 @@ class CodeBuildClient:
         buildBatchConfig: "ProjectBuildBatchConfigTypeDef" = None,
     ) -> UpdateProjectOutputTypeDef:
         """
-        [Client.update_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.update_project)
+        [Client.update_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.update_project)
         """
 
     def update_report_group(
@@ -590,7 +589,7 @@ class CodeBuildClient:
         tags: List["TagTypeDef"] = None,
     ) -> UpdateReportGroupOutputTypeDef:
         """
-        [Client.update_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.update_report_group)
+        [Client.update_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.update_report_group)
         """
 
     def update_webhook(
@@ -602,7 +601,7 @@ class CodeBuildClient:
         buildType: Literal["BUILD", "BUILD_BATCH"] = None,
     ) -> UpdateWebhookOutputTypeDef:
         """
-        [Client.update_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Client.update_webhook)
+        [Client.update_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Client.update_webhook)
         """
 
     @overload
@@ -610,7 +609,7 @@ class CodeBuildClient:
         self, operation_name: Literal["describe_code_coverages"]
     ) -> DescribeCodeCoveragesPaginator:
         """
-        [Paginator.DescribeCodeCoverages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages)
+        [Paginator.DescribeCodeCoverages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages)
         """
 
     @overload
@@ -618,7 +617,7 @@ class CodeBuildClient:
         self, operation_name: Literal["describe_test_cases"]
     ) -> DescribeTestCasesPaginator:
         """
-        [Paginator.DescribeTestCases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)
+        [Paginator.DescribeTestCases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)
         """
 
     @overload
@@ -626,7 +625,7 @@ class CodeBuildClient:
         self, operation_name: Literal["list_build_batches"]
     ) -> ListBuildBatchesPaginator:
         """
-        [Paginator.ListBuildBatches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches)
+        [Paginator.ListBuildBatches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches)
         """
 
     @overload
@@ -634,13 +633,13 @@ class CodeBuildClient:
         self, operation_name: Literal["list_build_batches_for_project"]
     ) -> ListBuildBatchesForProjectPaginator:
         """
-        [Paginator.ListBuildBatchesForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject)
+        [Paginator.ListBuildBatchesForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_builds"]) -> ListBuildsPaginator:
         """
-        [Paginator.ListBuilds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
+        [Paginator.ListBuilds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
         """
 
     @overload
@@ -648,13 +647,13 @@ class CodeBuildClient:
         self, operation_name: Literal["list_builds_for_project"]
     ) -> ListBuildsForProjectPaginator:
         """
-        [Paginator.ListBuildsForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
+        [Paginator.ListBuildsForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_projects"]) -> ListProjectsPaginator:
         """
-        [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
+        [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
         """
 
     @overload
@@ -662,13 +661,13 @@ class CodeBuildClient:
         self, operation_name: Literal["list_report_groups"]
     ) -> ListReportGroupsPaginator:
         """
-        [Paginator.ListReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)
+        [Paginator.ListReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_reports"]) -> ListReportsPaginator:
         """
-        [Paginator.ListReports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)
+        [Paginator.ListReports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)
         """
 
     @overload
@@ -676,7 +675,7 @@ class CodeBuildClient:
         self, operation_name: Literal["list_reports_for_report_group"]
     ) -> ListReportsForReportGroupPaginator:
         """
-        [Paginator.ListReportsForReportGroup documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)
+        [Paginator.ListReportsForReportGroup documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)
         """
 
     @overload
@@ -684,7 +683,7 @@ class CodeBuildClient:
         self, operation_name: Literal["list_shared_projects"]
     ) -> ListSharedProjectsPaginator:
         """
-        [Paginator.ListSharedProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)
+        [Paginator.ListSharedProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)
         """
 
     @overload
@@ -692,8 +691,5 @@ class CodeBuildClient:
         self, operation_name: Literal["list_shared_report_groups"]
     ) -> ListSharedReportGroupsPaginator:
         """
-        [Paginator.ListSharedReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)
+        [Paginator.ListSharedReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)
         """
-
-    def get_paginator(self, operation_name: str) -> Boto3Paginator:
-        pass
